@@ -18,6 +18,7 @@ static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magi
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#include <unistd.h>
 
 #include "tcltk/tclmagic.h"
 #include "utils/magic.h"
@@ -875,14 +876,14 @@ defExemptWireFunc(
     Rect r;
 
     /* Do not change the client data of tiles that have been processed! */
-    if (tile->ti_client != (ClientData) 1)
+    if (TiGetClientINT(tile) != 1)
     {
 	/* Ignore contacts, which need additional processing */
 	if (DBIsContact(TiGetType(tile))) return 0;
 
 	TiToRect(tile, &r);
 	if (GEO_SURROUND(rect, &r))
-	    tile->ti_client = (ClientData) 2;
+	    TiSetClientINT(tile, 2);
     }
     return 0;
 }
